@@ -2,12 +2,11 @@
 # against jira.atlassian.com.
 from jira.client import GreenHopper
 
-# By default, the client will connect to a JIRA instance started from the Atlassian Plugin SDK
+# By default, the client will connect to a Jira instance started from the Atlassian Plugin SDK
 # (see https://developer.atlassian.com/display/DOCS/Installing+the+Atlassian+Plugin+SDK for details).
 # Override this with the options parameter.
-# GreenHopper is a plugin in a JIRA instance
-options = {
-    'server': 'https://jira.atlassian.com'}
+# GreenHopper is a plugin in a Jira instance
+options = {"server": "https://jira.atlassian.com"}
 gh = GreenHopper(options)
 
 # Get all boards viewable by anonymous users.
@@ -17,11 +16,3 @@ boards = gh.boards()
 board_id = 441
 print("GreenHopper board: %s (%s)" % (boards[0].name, board_id))
 sprints = gh.sprints(board_id)
-
-# List the incomplete issues in each sprint
-for sprint in sprints:
-    sprint_id = sprint.id
-    print("Sprint: %s" % sprint.name)
-    incompleted_issues = gh.incompleted_issues(board_id, sprint_id)
-    print("Incomplete issues: %s" %
-          ', '.join(issue.key for issue in incompleted_issues))
