@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""JIRA utils used internally."""
-from __future__ import unicode_literals
+"""Jira utils used internally."""
 import threading
 
 from jira.resilientsession import raise_on_error
@@ -15,7 +14,7 @@ class CaseInsensitiveDict(dict):
 
     All keys are expected to be strings. The structure remembers the
     case of the last key to be set, and ``iter(instance)``,
-    ``keys()``, ``items()``, ``iterkeys()``, and ``iteritems()``
+    ``keys()``, ``items()``, ``iterkeys()``
     will contain case-sensitive keys. However, querying and contains
     testing is case insensitive::
 
@@ -38,7 +37,7 @@ class CaseInsensitiveDict(dict):
         super(CaseInsensitiveDict, self).__init__(*args, **kw)
 
         self.itemlist = {}
-        for key, value in super(CaseInsensitiveDict, self).items():
+        for key, value in super(CaseInsensitiveDict, self).copy().items():
             if key != key.lower():
                 self[key.lower()] = value
                 self.pop(key, None)
@@ -64,13 +63,11 @@ class CaseInsensitiveDict(dict):
 
 def threaded_requests(requests):
     for fn, url, request_args in requests:
-        th = threading.Thread(
-            target=fn, args=(url,), kwargs=request_args, name=url,
-        )
+        th = threading.Thread(target=fn, args=(url,), kwargs=request_args, name=url)
         th.start()
 
     for th in threading.enumerate():
-        if th.name.startswith('http'):
+        if th.name.startswith("http"):
             th.join()
 
 
